@@ -4,10 +4,18 @@
 ( cd opt/kde/share/doc/HTML/da/kdf ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kdm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kdm ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kig ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kig ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/juk ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/juk ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kpf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kpf ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/ktuberling ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/ktuberling ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/amor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/amor ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/karm ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/karm ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kate ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kate ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kdat ; rm -rf common )
@@ -16,6 +24,14 @@
 ( cd opt/kde/share/doc/HTML/da/kdvi ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kgeo ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kgeo ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kget ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kget ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kgpg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kgpg ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kmag ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kmag ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kmid ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kmid ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kmix ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kmix ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kodo ; rm -rf common )
@@ -24,10 +40,26 @@
 ( cd opt/kde/share/doc/HTML/da/kolf ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kpat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kpat ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kpdf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kpdf ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/korn ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/korn ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kppp ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kppp ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/krdc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/krdc ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/krec ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/krec ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/krfb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/krfb ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kscd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kscd ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/ksim ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/ksim ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/lisa ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/lisa ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kxkb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kxkb ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kalzium ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kalzium ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/katomic ; rm -rf common )
@@ -36,24 +68,34 @@
 ( cd opt/kde/share/doc/HTML/da/ksysguard ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kbounce ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kbounce ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kdearch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kdearch ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kbattleship ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kbattleship ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kaboodle ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kaboodle ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/knewsticker ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/knewsticker ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/khangman ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/khangman ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kfloppy ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kfloppy ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/cervisia ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/cervisia ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/khexedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/khexedit ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kpercentage ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kpercentage ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kandy ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kandy ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kcalc ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kcalc ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kdesu ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kdesu ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kcron ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kcron ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kdict ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kdict ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kedit ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kfind ; rm -rf common )
@@ -66,10 +108,14 @@
 ( cd opt/kde/share/doc/HTML/da/kmail ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kmoon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kmoon ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/knode ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/knode ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kooka ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kooka ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/ksame ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/ksame ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/ksirc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/ksirc ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/ksysv ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/ksysv ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/ktron ; rm -rf common )
@@ -82,16 +128,28 @@
 ( cd opt/kde/share/doc/HTML/da/kwin4 ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/lskat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/lskat ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kgoldrunner ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kgoldrunner ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kcoloredit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/klipper ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/klipper ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kvoctrain ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kvoctrain ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kmousetool ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kmousetool ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/ksnapshot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kompare ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kompare ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kontact ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kontact ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/konsole ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/konsole ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/konsolekalendar ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/konsolekalendar ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcachegrind ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcachegrind ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kpackage ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kpackage ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/khelpcenter/faq ; rm -rf common )
@@ -114,14 +172,26 @@
 ( cd opt/kde/share/doc/HTML/da/konquest ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kspaceduel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kverbos ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kverbos ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kwallet ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kwallet ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kweather ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kweather ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kwuftpd ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kwuftpd ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kxsldbg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kxsldbg ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kwifimanager ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kwifimanager ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kbugbuster ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kmenuedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kioslave ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kioslave ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/flashkard ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/flashkard ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kbackgammon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kaddressbook ; rm -rf common )
@@ -164,6 +234,8 @@
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/grad.png grad.png )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf kde-web.css )
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
+( cd opt/kde/share/doc/HTML/da/common ; rm -rf kde_logo_bg.png )
+( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf doxygen.css )
@@ -178,12 +250,16 @@
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/da/common ; rm -rf appheader.html )
+( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf doctop1.png )
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf doctop2.png )
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf shadow.png )
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/shadow.png shadow.png )
+( cd opt/kde/share/doc/HTML/da/common ; rm -rf kde_logo.png )
+( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/da/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
 ( cd opt/kde/share/doc/HTML/da/common ; rm -rf fdl-license.html )
@@ -258,8 +334,12 @@
 ( cd opt/kde/share/doc/HTML/da/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kcontrol/kmixcfg ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/desktopbehavior ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/desktopbehavior ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kcontrol/passwords ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/panelappearance ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kcontrol/panelappearance ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kcontrol/ebrowsing ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kcontrol/background ; rm -rf common )
@@ -320,32 +400,50 @@
 ( cd opt/kde/share/doc/HTML/da/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kbabel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kbabel ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kalarm ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kalarm ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kamera ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kamera ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kdeprint ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kdeprint ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kasteroids ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kasteroids ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kbruch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kbruch ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/keduca ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/keduca ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kgamma ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kgamma ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kmessedwords ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kdevelop ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kdevelop ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kicker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kicker ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/klines ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/klines ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kmines ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kmines ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kmouth ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kmouth ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kmplot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kmplot ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/knotes ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/knotes ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kpager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kpager ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kpaint ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kpaint ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kopete ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kopete ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kpilot ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kpilot ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kpoker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kpoker ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kruler ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kruler ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/ktalkd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/ktalkd ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/ksnake ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/ksnake ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kspell ; rm -rf common )
@@ -364,30 +462,38 @@
 ( cd opt/kde/share/doc/HTML/da/kreversi ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/noatun ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/noatun ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/ksplashml ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/ksplashml ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kdebugdialog ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kblackbox ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kblackbox ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kcharselect ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kcharselect ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/quanta ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/quanta ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kuickshow ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kuickshow ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kde_app_devel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kde_app_devel ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kiconedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kiconedit ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/klettres ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/klettres ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kfouleggs ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/da/common common )
-( cd opt/kde/share/doc/HTML/da/kaphorism ; rm -rf common )
-( cd opt/kde/share/doc/HTML/da/kaphorism ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kghostview ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kghostview ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/klickety ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/klickety ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kpovmodeler ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kjumpingcube ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kenolaba ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kenolaba ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kgpgcertmanager ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kworldclock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kworldclock ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/KRegExpEditor ; rm -rf common )
@@ -396,6 +502,8 @@
 ( cd opt/kde/share/doc/HTML/da/ksokoban ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kteatime ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kteatime ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/kmathtool ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/kmathtool ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kinfocenter/dma ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kinfocenter/pci ; rm -rf common )
@@ -434,6 +542,8 @@
 ( cd opt/kde/share/doc/HTML/da/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/kate-plugins ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/da/common common )
+( cd opt/kde/share/doc/HTML/da/umbrello ; rm -rf common )
+( cd opt/kde/share/doc/HTML/da/umbrello ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/konqueror ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/da/konqueror ; ln -sf /opt/kde/share/doc/HTML/da/common common )
 ( cd opt/kde/share/doc/HTML/da/korganizer ; rm -rf common )
